Two versions of the Gmsh MSH format are covered here: 2.2 and 4.1.

The meshes were generated by Gmsh 4.2.2-git-0766f664d from the same Gmsh GEO file `insulated.geo` as shown in the `Makefile` (`make -j2`); the difference is that the first was passed `-format msh2`, MSH4.1 being the default.

The meshes are coarse versions of a real finite element example and contain 111 3-node triangular domain elements, divided into two Physical Surfaces, and 21 2-node line boundary elements, in a single Physical Line.